import seaborn as sns
import matplotlib.pyplot as plt
import pandas as pd

# Apply the default theme
sns.set_theme()

def plotopt():
    print('What do you want to plot?')
    print('''1. Air force on the ice in front of the system
2. Force on the dam due to the air
3. Force on the mooring due to the air
4. Stresses caused by the thermal expansion
5. Maximum extension of each joint
6. EXIT''')

i = 0
while i < 10:
    plotopt()
    if int(input()) == 1: # Air force on ice in front of system
        # Import data
        info = pd.read_csv(r'./Data/DataFrames/info.csv', index_col=0, decimal=',')
        info.index.names = ["Date"]
        info.index = pd.to_datetime(info.index, format='%Y-%m-%d')
        # Create a visualization
        sns.relplot(data=info["Fa (N)"], kind="line")
        plt.show()
        print('Press any key to go back to the plot menu')
        input()
        plotopt()
    if int(input()) == 2: # Force on the dam due to the air
        # Import data
        drag = pd.read_csv(r'./Data/DataFrames/drag.csv', index_col=0, decimal=',')
        drag.index.names = ["Date"]
        drag.index = pd.to_datetime(drag.index, format='%Y-%m-%d')
        # Create a visualization
        sns.relplot(data=drag["Drag force with ice (N)"], kind="line")
        plt.show()
        print('Press any key to go back to the plot menu')
        input()
        plotopt()
    if int(input()) == 3: # Force on the mooring due to the air
        # Import data
        drag = pd.read_csv(r'./Data/DataFrames/drag.csv', index_col=0, decimal=',')
        drag.index.names = ["Date"]
        drag.index = pd.to_datetime(drag.index, format='%Y-%m-%d')
        # Create a visualization
        sns.relplot(data=drag["Drag force without ice (N)"], kind="line")
        plt.show()
        print('Press any key to go back to the plot menu')
        input()
        plotopt()
    if int(input()) == 4: # Stresses caused by the thermal expansion
        # Import data
        daymaxt = pd.read_csv(r'./Data/DataFrames/daymaxt.csv', index_col=0, decimal=',')
        daymaxt.index.names = ["Date"]
        daymaxt.index = pd.to_datetime(daymaxt.index, format='%Y-%m-%d')
        daymaxt.reset_index(level=0, inplace=True)
        daymaxt=daymaxt.melt(id_vars=['Date','mintemp (C)','maxtemp (C)','increaseLength (mm)','increaseWidth (mm)','increaseLengthperJoint (mm)','increaseWidthperJoint (mm)' ], var_name='Stress' ,value_name='(kPa)')
        daymaxt['(kPa)'] = daymaxt['(kPa)'] * 1000000
        # Create a visualization
        sns.relplot(x = 'Date', y = '(kPa)', hue='Stress', data = daymaxt, kind="line")
        plt.show()
        print('Press any key to go back to the plot menu')
        input()
        plotopt()
    if int(input()) == 5: # Maximum extension of each joint
        # Import data
        daymaxt = pd.read_csv(r'./Data/DataFrames/daymaxt.csv', index_col=0, decimal=',')
        daymaxt.index.names = ["Date"]
        daymaxt.index = pd.to_datetime(daymaxt.index, format='%Y-%m-%d')
        daymaxt.reset_index(level=0, inplace=True)
        daymaxt = daymaxt.melt(id_vars=['Date', 'mintemp (C)', 'maxtemp (C)', 'increaseLength (mm)', 'increaseWidth (mm)','EquivalentStressL (GPa)', 'EquivalentStressW (GPa)'], var_name='Deformation',value_name='(mm)')
        # Create a visualization
        sns.relplot(x = 'Date', y = '(mm)', hue='Deformation', data = daymaxt, kind="line")
        plt.show()
        print('Press any key to go back to the plot menu')
        input()
        plotopt()
    else:
        print('Exiting')

''' # Code for drag comparison
drag = pd.read_csv(r'./Data/DataFrames/drag.csv', index_col=0, decimal=',')
drag.index.names = ["Date"]
drag.index = pd.to_datetime(drag.index, format='%Y-%m-%d')
drag.reset_index(level=0, inplace=True)
drag = drag.melt(id_vars=['Date', 'wSpeed (m/s)', 'Drag force without ice (N)'], var_name='Forces', value_name='(N)')
sns.relplot(x='Date', y='(N)', hue='Forces', data=drag, kind="line")
'''