import pandas as pd
from sympy.solvers import solve
from sympy import Symbol

df = pd.read_csv('./Data/temporary.txt', sep="\t", index_col=0)
wind = df[['wSpeed.10']]
wind.index = pd.to_datetime(wind.index)

# Get the maximum hourly wind speed per month
monthmax = pd.DataFrame()
monthmax = wind.resample('m').max()
monthmax.columns = ['wSpeed']

# Import ice csv
ice = pd.read_csv('./Data/Ice thickness.csv', sep="|", index_col=0)
ice.columns = ['iThickness']

# Import snow csv
snow = pd.read_csv('./Data/Snow thickness.csv', sep="|", index_col=0)
snow.columns = ['sThickness']

# Create a DataFrame with wind speed, ice thickness and snow thickness
info = monthmax
month = []
for i in range(1999, 2021, 1):
    for j in range(1, 13, 1):
        month.append('%i-%i' % (i, j))
for i in range(2021, 2022, 1):
    for j in range(1, 8, 1):
        month.append('%i-%i' % (i, j))
info.index = month
info.index = pd.to_datetime(info.index)
info.reset_index(level=0, inplace=True)
info = info.join(ice).join(snow)
info = info.set_index('index')

# Remove from june to november (no ice)
info = info.drop(info.index[info.index.month.isin([6, 7, 8, 9, 10, 11])])

# Get maximum for each month
monthmaxice = info['iThickness'].groupby(info.index.month).max()
monthmaxsnow = info['sThickness'].groupby(info.index.month).max()

# Add estimations of max ice and snow in May (no data)
monthmaxice[5] = 53
monthmaxsnow[5] = 0

# Check months and substitute NaN for maximum (worst case scenario)
info.reset_index(level=0, inplace=True)
for i in info[info.iThickness.isnull()].index:
    info.loc[i, 'iThickness'] = monthmaxice[info.loc[i, 'index'].month]
for i in info[info.sThickness.isnull()].index:
    info.loc[i, 'sThickness'] = monthmaxsnow[info.loc[i, 'index'].month]
info = info.set_index('index')

# Calculate drifting force
Area = 1500000  # 1.5 km2 (maximum area that the air can push against the dam), max lake area=4 km2
aDensity = 1.367    # kg/m3 at -15ºC
Ca = 0.002
Fa = []
info.reset_index(level=0, inplace=True)
for i in range(0, len(info), 1):
    if info.at[i, 'iThickness'] != 0:
        Fa.insert(i, aDensity * Ca * Area * info.at[i, 'wSpeed'] ** 2)
    else:
        Fa.insert(i, 0)
info = info.assign(Fa=Fa)
info = info.set_index('index')

# Calculate force required to build a ridge
lr = 1000  # m, width of the ridge
A = 4    # Empirical factor (2-10, but closer to 2)
Fr = []
info.reset_index(level=0, inplace=True)
for i in range(0, len(info), 1):
    Fr.insert(i, A * lr ** 0.46 * (info.at[i, 'iThickness'] / 100) ** 1.25 * 1000000)   # CHECK WITH KNUT
info = info.assign(Fr=Fr)
info = info.set_index('index')


# Check if a ridge can be created
Ridge = []
info.reset_index(level=0, inplace=True)
for i in range(0, len(info), 1):
    if ((info.at[i, 'Fa'] >= info.at[i, 'Fr']) and (info.at[i, 'Fr'] != 0)):
        Ridge.insert(i, 'YES')
    else:
        Ridge.insert(i, 'NO')
info = info.assign(Ridge=Ridge)
info = info.set_index('index')
Ridges = info[info['Ridge'].str.contains("YES")]

#Check the maximum force that the dam will support
if len(Ridges.index) == 0:
    Max_force = info['Fa'].max()
else:
    for i in range(0, len(info), 1):
        if ((info.at[i, 'Ridge'] == "YES") and (info.at[i, 'Fr'] >= Max_force)):
            Max_force = info['Fr'].max()
print ('Max force %sN' % Max_force)

# Properly name columns
info.columns = ['wSpeed (m/s)','iThickness (cm)','sThickness (cm)','Fa (N)','Fr (N)','Ridge']
# Export info DataFrame
info.to_csv(r'./Data/DataFrames/info.csv', decimal=',')
df1 = df.resample('D').ffill()

'''#Check ice thickness required for the ridge to create
Area = 2000000  # 1.5 km2 (maximum area that the air can push against the dam), max lake area=4 km2
aDensity = 1.367    # kg/m3 at -15ºC
Ca = 0.002
lr = 400  # m, width of the ridge
A = 4    # Empirical factor (2-10, but closer to 2)
Icethick = []
info.reset_index(level=0, inplace=True)
for i in range(0, len(info), 1):
    x = Symbol('x')
    Icethick.insert(i, print(solve(A*(lr**0.46)*((x/100)**1.25)*1000000-info.at[i, 'Fa (N)'])))
info = info.assign(Icethick=Icethick)
info = info.set_index('index')'''
