import pandas as pd

df = pd.read_csv('./Data/temporary.txt', sep="\t", index_col=0)
temp = df[['temp.10']]
temp.index = pd.to_datetime(temp.index)

# Get the maximum and minimum hourly temperatures per day
daymaxt = pd.DataFrame()
daymaxt = temp.resample('d').min()
daymaxt.columns = ['mintemp']
daymint =pd.DataFrame()
daymint = temp.resample('d').max()
daymint.columns = ['maxtemp']
daymaxt = daymaxt.join(daymint)

# Delete the months without ice
daymaxt = daymaxt.drop(daymaxt.index[daymaxt.index.month.isin([6, 7, 8, 9, 10, 11])])

# Calculate stress and displacement total and per joint
Length = 1947.5    # Length of the whole grid (m)
Width = 1572.5     # Width of the whole grid (m)
BlocksL = 26
BlocksW = 15
JointsL = 12 * BlocksL - 2
JointsW = 12 * BlocksW - 2
E = 9   # GPa 4-9, 9 is the wcs
Lengthincrease = []
Widthincrease = []
Lengthincreasepj = []
Widthincreasepj = []
EqStressL = []   # E = stress / strain
EqStressW = []
daymaxt.reset_index(level=0, inplace=True)
for i in range(0, len(daymaxt), 1):
    Lengthincrease.insert(i, (54 + 0.18 * daymaxt.at[i, 'maxtemp']) * 10 ** (-6) * Length * (daymaxt.at[i, 'maxtemp']-daymaxt.at[i, 'mintemp']) * 1000)
    Widthincrease.insert(i, (54 + 0.18 * daymaxt.at[i, 'maxtemp']) * 10 ** (-6) * Width * (daymaxt.at[i, 'maxtemp']-daymaxt.at[i, 'mintemp']) * 1000)
    Lengthincreasepj.insert(i, Lengthincrease[i] / JointsL)
    Widthincreasepj.insert(i, Lengthincrease[i] / JointsW)
    EqStressW.insert(i, E * (Widthincreasepj[i] / (Width * 1000)))
    EqStressL.insert(i, E * (Lengthincreasepj[i] / (Length * 1000)))
daymaxt = daymaxt.assign(Lengthincrease=Lengthincrease).assign(Widthincrease=Widthincrease).assign(Widthincreasepj = Widthincreasepj).assign(Lengthincreasepj = Lengthincreasepj).assign(EqStressW=EqStressW).assign(EqStressL=EqStressL)
daymaxt = daymaxt.set_index('time')

#Show end results
maxincwidth = daymaxt.Widthincrease.max()
print ('Max increase in Width %s mm' % daymaxt.Widthincrease.max())
maxinclength = daymaxt.Lengthincrease.max()
print ('Max increase in Length %s mm' % daymaxt.Lengthincrease.max())
maxincwidthjoint = daymaxt.Widthincreasepj.max()
print ('Max increase per Width joint %s mm' % daymaxt.Widthincreasepj.max())
maxinclengthjoint = daymaxt.Lengthincreasepj.max()
print ('Max increase per Length joint %s mm' % daymaxt.Lengthincreasepj.max())
maxstresslengthjoint = daymaxt.EqStressL[daymaxt.Lengthincrease.idxmax()]
print ('Max stress per joint %s GPa length' % daymaxt.EqStressL[daymaxt.Lengthincrease.idxmax()])
maxstresswidthjoint = daymaxt.EqStressW[daymaxt.Widthincrease.idxmax()]
print ('Max stress per joint %s GPa width' % daymaxt.EqStressW[daymaxt.Widthincrease.idxmax()])

#Properly name columns
daymaxt.columns = ['mintemp (C)','maxtemp (C)','increaseLength (mm)','increaseWidth (mm)','increaseWidthperJoint (mm)','increaseLengthperJoint (mm)','EquivalentStressW (GPa)','EquivalentStressL (GPa)']

# Export daymaxt DataFrame
daymaxt.to_csv(r'./Data/DataFrames/daymaxt.csv', decimal=',')
